#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_scheduler.interfaces.url import IURLCallerTask, IURLCallerTaskInfo
from pyams_skin.interfaces.viewlet import IToolbarAddingMenu
from pyams_skin.layer import IPyAMSLayer
from zope.component.interfaces import ISite

# import packages
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_scheduler.url import URLCallerTask
from pyams_scheduler.zmi.scheduler import SchedulerTasksTable
from pyams_scheduler.zmi.task import TaskBaseAddForm
from pyams_skin.viewlet.toolbar import ToolbarMenuItem
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from pyams_scheduler import _


@viewlet_config(name='add-scheduler-url-task.menu', context=ISite, layer=IPyAMSLayer,
                view=SchedulerTasksTable, manager=IToolbarAddingMenu,
                permission='system.manage', weight=5)
class URLTaskAddMenu(ToolbarMenuItem):
    """URL caller task add menu"""

    label = _("Add URL caller task...")
    label_css_class = 'fa fa-fw fa-globe'
    url = 'add-scheduler-url-task.html'
    modal_target = True


@pagelet_config(name='add-scheduler-url-task.html', context=ISite, layer=IPyAMSLayer,
                permission='system.manage')
class URLTaskAddForm(TaskBaseAddForm):
    """URL caller task add form"""

    legend = _("Add URL caller task")
    icon_css_class = 'fa fa-fw fa-globe'

    ajax_handler = 'add-scheduler-url-task.json'
    task_factory = URLCallerTask


@view_config(name='add-scheduler-url-task.json', context=ISite, request_type=IPyAMSLayer,
             permission='system.manage', renderer='json', xhr=True)
class URLTaskAJAXAddForm(AJAXAddForm, URLTaskAddForm):
    """URL caller task add form, AJAX view"""


@pagelet_config(name='settings.html', context=IURLCallerTask, layer=IPyAMSLayer, permission='system.view')
class URLTaskEditForm(AdminDialogEditForm):
    """URL caller task edit form"""

    @property
    def title(self):
        translate = self.request.localizer.translate
        return translate(_("Scheduler task: {0}")).format(self.context.name)

    legend = _("Edit task settings")
    icon_css_class = 'fa fa-fw fa-globe'

    fields = field.Fields(IURLCallerTaskInfo)
    ajax_handler = 'settings.json'
    edit_permission = 'system.manage'


@view_config(name='settings.json', context=IURLCallerTask, request_type=IPyAMSLayer,
             permission='system.manage', renderer='json', xhr=True)
class URLTaskAJAXEditForm(AJAXEditForm, URLTaskEditForm):
    """URL caller task edit form, AJAX view"""
